==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/ASSETINVENTORYRESULTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour ASSETINVENTORYRESULTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ASSETINVENTORYRESULTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASSETINVENTORYRESULTID_Type", propOrder = {
    "dbsessionid",
    "assetid"
})
public class ASSETINVENTORYRESULTID_Type {

    @XmlElement(name = "DBSESSIONID", required = true)
    protected QUANTITY dbsessionid;
    @XmlElement(name = "ASSETID", required = true)
    protected EQUIPMENTID_Type assetid;

    /**
     * Obtient la valeur de la propriété dbsessionid.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDBSESSIONID() {
        return dbsessionid;
    }

    /**
     * Définit la valeur de la propriété dbsessionid.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDBSESSIONID(QUANTITY value) {
        this.dbsessionid = value;
    }

    /**
     * Obtient la valeur de la propriété assetid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Définit la valeur de la propriété assetid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/ASSETINVENTORYRESULTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for ASSETINVENTORYRESULTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ASSETINVENTORYRESULTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASSETINVENTORYRESULTID_Type", propOrder = {
    "dbsessionid",
    "assetid"
})
public class ASSETINVENTORYRESULTID_Type {

    @XmlElement(name = "DBSESSIONID", required = true)
    protected QUANTITY dbsessionid;
    @XmlElement(name = "ASSETID", required = true)
    protected EQUIPMENTID_Type assetid;

    /**
     * Gets the value of the dbsessionid property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDBSESSIONID() {
        return dbsessionid;
    }

    /**
     * Sets the value of the dbsessionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDBSESSIONID(QUANTITY value) {
        this.dbsessionid = value;
    }

    /**
     * Gets the value of the assetid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Sets the value of the assetid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

}
